@@ -2,7 +2,7 @@
 
 __author__ = """gigahanma"""
 __email__ = 'random@example.com'
-__version__ = '0.0.6'
-from simplereader import *
+__version__ = '0.0.7'
+from .simplereader import *
 
 
